@@ -439,6 +439,31 @@ EO
 		label_ru => ' URL,    ,       ,      \'_\'.       "href",      ',
 		see_also => [qw(check_href)],
 	},
+
+					#######################################
+
+	{
+		name     => 'check_title',
+#		options  => [qw()],
+		syn      => <<EO,	
+	check_title ({
+		...
+		label => 'project "Y"',
+		...
+	});
+
+	# --> {	
+	# ...
+	# label => 'project "Y"',
+	# title => 'title="project &amp;quot;Y&amp;quot;"'
+	# ...
+	# }	
+	
+EO
+		label_en => 'Adds a properly quoted TITLE tag to options hashref. Defaults to label option.',
+		label_ru => '   HTML-   TITLE.       label.',
+		see_also => [qw(create_url)],
+	},
 				
 					#######################################
 
